@@ -74,7 +74,7 @@ class Easyocrpipleline:
                 tif_file_path=path
             else:
                 img.seek(i)
-                tif_file_path=('folder/'+tif_file_name+'(%s).tif'%(i,))
+                tif_file_path=('/tmp/'+tif_file_name+'(%s).tif'%(i,))
                 img.save(tif_file_path)
             tif_file = cv2.imread(tif_file_path)  # in case of tif
             result = reader.readtext(tif_file, width_ths=0)
@@ -92,7 +92,7 @@ class Easyocrpipleline:
         file_name = path.split('/')[-1]
         file_name = file_name.split('.')[0]
         for index, image in enumerate(images):
-            path = 'folder/'+file_name+'('+str(index)+').jpg'
+            path = '/tmp/'+file_name+'('+str(index)+').jpg'
             image.save(path)
             self.image_process(path)
 
